@@ -4,7 +4,7 @@
 #
 # Miscellaneous utility functions used throughout the library.
 #
-from collections import Counter, defaultdict, OrderedDict
+from collections import Counter, defaultdict, OrderedDict, namedtuple
 
 from pelote.shim import is_dataframe
 
@@ -25,25 +25,6 @@ def has_mixed_types(iterable) -> bool:
     return False
 
 
-def check_node_exists(g, n):
-    if n not in g:
-        raise KeyError("Node {} does not exist. {}".format(n, g.nodes))
-
-    return n
-
-
-def dict_without(d, k: str):
-    o = {}
-
-    for n, v in d.items():
-        if n == k:
-            continue
-
-        o[n] = v
-
-    return o
-
-
 CONSTANT_TIME_LOOKUP = (set, frozenset, dict, Counter, defaultdict, OrderedDict)
 
 
@@ -61,3 +42,23 @@ def iterator_from_dataframe(table, columns=None):
         )
     else:
         return table
+
+
+Representation = namedtuple("Representation", ("max", "code"))
+
+UINT_REPRESENTATIONS = [
+    Representation(2**8 - 1, "B"),
+    Representation(2**16 - 1, "H"),
+    Representation(2**32 - 1, "L"),
+    Representation(2**64 - 1, "Q"),
+]
+
+
+def uint_representation_for_capacity(capacity):
+    max_int = capacity - 1
+
+    for r in UINT_REPRESENTATIONS:
+        if max_int <= r.max:
+            return r
+
+    raise TypeError("capacity is over 64 bits")
