@@ -3,7 +3,7 @@
 # =============================================================================
 import networkx as nx
 
-from pelote.metrics.chiba_nishizeki import triangles
+from pelote.metrics.chiba_nishizeki import triangles, triangular_strength
 
 
 class TestChibaNishizeki(object):
@@ -37,3 +37,19 @@ class TestChibaNishizeki(object):
         T = set(triangles(graph))
 
         assert T == {("B", "D", "C"), ("B", "F", "A"), ("B", "E", "F"), ("G", "I", "H")}
+
+    def test_triangular_strength(self):
+        graph = nx.Graph()
+
+        graph.add_edge(0, 1)
+        graph.add_edge(1, 2)
+        graph.add_edge(2, 3)
+        graph.add_edge(3, 1)
+
+        strengths = triangular_strength(graph)
+
+        assert strengths == {(1, 2): 1, (2, 3): 1, (1, 3): 1}
+
+        strengths = triangular_strength(graph, full=True)
+
+        assert strengths == {(1, 2): 1, (2, 3): 1, (1, 3): 1, (0, 1): 0}
